@@ -1,4 +1,4 @@
-﻿define(['dialogHelper', 'jQuery', 'paper-checkbox', 'paper-input', 'paper-item-body', 'paper-icon-item', 'paper-textarea', 'paper-fab'], function (dialogHelper, $) {
+﻿define(['dialogHelper', 'datetime', 'jQuery', 'emby-checkbox', 'emby-input', 'emby-select', 'listViewStyle', 'emby-textarea', 'emby-button', 'paper-icon-button-light'], function (dialogHelper, datetime, $) {
 
     var currentContext;
     var metadataEditorInfo;
@@ -96,7 +96,7 @@
 
         if (currentItem[property]) {
 
-            var date = parseISO8601Date(currentItem[property], { toLocal: true });
+            var date = datetime.parseISO8601Date(currentItem[property], true);
 
             var parts = date.toISOString().split('T');
 
@@ -122,6 +122,7 @@
             var item = {
                 Id: currentItem.Id,
                 Name: $('#txtName', form).val(),
+                OriginalTitle: $('#txtOriginalName', form).val(),
                 ForcedSortName: $('#txtSortName', form).val(),
                 DisplayMediaType: $('#txtDisplayMediaType', form).val(),
                 CommunityRating: $('#txtCommunityRating', form).val(),
@@ -132,7 +133,6 @@
                 CriticRating: $('#txtCriticRating', form).val(),
                 CriticRatingSummary: $('#txtCriticRatingSummary', form).val(),
                 IndexNumber: $('#txtIndexNumber', form).val() || null,
-                DisplaySpecialsWithSeasons: form.querySelector('#chkDisplaySpecialsInline').checked,
                 AbsoluteEpisodeNumber: $('#txtAbsoluteEpisodeNumber', form).val(),
                 DvdEpisodeNumber: $('#txtDvdEpisodeNumber', form).val(),
                 DvdSeasonNumber: $('#txtDvdSeasonNumber', form).val(),
@@ -247,7 +247,7 @@
     }
 
     function removeElementFromListview(source) {
-        $(source).parents('paper-icon-item').remove();
+        $(source).parents('.listItem').remove();
     }
 
     function editPerson(context, person, index) {
@@ -269,101 +269,33 @@
 
     function showRefreshMenu(context, button) {
 
-        var items = [];
-
-        items.push({
-            name: Globalize.translate('ButtonLocalRefresh'),
-            id: 'local',
-            ironIcon: 'refresh'
+        require(['refreshDialog'], function (refreshDialog) {
+            new refreshDialog({
+                itemIds: [currentItem.Id],
+                serverId: ApiClient.serverInfo().Id
+            }).show();
         });
-
-        items.push({
-            name: Globalize.translate('ButtonAddMissingData'),
-            id: 'missing',
-            ironIcon: 'refresh'
-        });
-
-        items.push({
-            name: Globalize.translate('ButtonFullRefresh'),
-            id: 'full',
-            ironIcon: 'refresh'
-        });
-
-        require(['actionsheet'], function (actionsheet) {
-
-            actionsheet.show({
-                items: items,
-                positionTo: button,
-                callback: function (id) {
-
-                    if (id) {
-                    
-                        Dashboard.showLoadingMsg();
-                        // For now this is a hack
-                        setTimeout(function () {
-                            Dashboard.hideLoadingMsg();
-                        }, 5000);
-                    }
-
-                    switch (id) {
-
-                        case 'local':
-                            ApiClient.refreshItem(currentItem.Id, {
-                                Recursive: true,
-                                ImageRefreshMode: 'None',
-                                MetadataRefreshMode: 'ValidationOnly',
-                                ReplaceAllImages: false,
-                                ReplaceAllMetadata: false
-                            });
-                            break;
-                        case 'missing':
-                            ApiClient.refreshItem(currentItem.Id, {
-                                Recursive: true,
-                                ImageRefreshMode: 'FullRefresh',
-                                MetadataRefreshMode: 'FullRefresh',
-                                ReplaceAllImages: false,
-                                ReplaceAllMetadata: false
-                            });
-                            break;
-                        case 'full':
-                            ApiClient.refreshItem(currentItem.Id, {
-                                Recursive: true,
-                                ImageRefreshMode: 'FullRefresh',
-                                MetadataRefreshMode: 'FullRefresh',
-                                ReplaceAllImages: false,
-                                ReplaceAllMetadata: true
-                            });
-                            break;
-                        default:
-                            break;
-                    }
-                }
-            });
-
-        });
-
     }
 
-    function showMoreMenu(context, button) {
+    function showMoreMenu(context, button, user) {
 
         var items = [];
 
         items.push({
             name: Globalize.translate('ButtonEditImages'),
-            id: 'images',
-            ironIcon: 'photo'
+            id: 'images'
         });
 
-        items.push({
-            name: Globalize.translate('ButtonIdentify'),
-            id: 'identify',
-            ironIcon: 'info'
-        });
+        if (LibraryBrowser.canIdentify(user, currentItem.Type)) {
+            items.push({
+                name: Globalize.translate('ButtonIdentify'),
+                id: 'identify'
+            });
+        }
 
         items.push({
             name: Globalize.translate('ButtonRefresh'),
-            id: 'refresh',
-            ironIcon: 'refresh'
+            id: 'refresh'
         });
 
         require(['actionsheet'], function (actionsheet) {
@@ -376,7 +308,9 @@
                     switch (id) {
 
                         case 'identify':
-                            LibraryBrowser.identifyItem(currentItem.Id);
+                            LibraryBrowser.identifyItem(currentItem.Id).then(function () {
+                                reload(context, currentItem.Id);
+                            });
                             break;
                         case 'refresh':
                             showRefreshMenu(context, button);
@@ -419,9 +353,11 @@
     }
 
     function onEditorClick(e) {
+
         var btnRemoveFromEditorList = parentWithClass(e.target, 'btnRemoveFromEditorList');
         if (btnRemoveFromEditorList) {
             removeElementFromListview(btnRemoveFromEditorList);
+            return;
         }
 
         var btnAddTextItem = parentWithClass(e.target, 'btnAddTextItem');
@@ -439,7 +375,10 @@
 
         context.querySelector('.btnMore').addEventListener('click', function (e) {
 
-            showMoreMenu(context, e.target);
+            Dashboard.getCurrentUser().then(function (user) {
+                showMoreMenu(context, e.target, user);
+            });
+
         });
 
         context.querySelector('.btnHeaderSave').addEventListener('click', function (e) {
@@ -566,15 +505,19 @@
 
             var labelText = Globalize.translate('LabelDynamicExternalId').replace('{0}', idInfo.Name);
 
-            html += '<div>';
+            html += '<div class="inputContainer">';
+            html += '<div style="display: flex; align-items: center;">';
 
             var value = providerIds[idInfo.Key] || '';
 
-            html += '<paper-input style="display:inline-block;width:80%;" class="txtExternalId" value="' + value + '" data-providerkey="' + idInfo.Key + '" data-formatstring="' + formatString + '" data-buttonclass="' + buttonId + '" id="' + id + '" label="' + labelText + '"></paper-input>';
+            html += '<div style="flex-grow:1;">';
+            html += '<input is="emby-input" class="txtExternalId" value="' + value + '" data-providerkey="' + idInfo.Key + '" data-formatstring="' + formatString + '" data-buttonclass="' + buttonId + '" id="' + id + '" label="' + labelText + '"/>';
+            html += '</div>';
 
             if (formatString) {
-                html += '<a class="clearLink ' + buttonId + '" href="#" target="_blank" data-role="none" style="float: none; width: 1.75em"><paper-icon-button icon="open-in-browser"></paper-icon-button></a>';
+                html += '<a class="clearLink ' + buttonId + '" href="#" target="_blank" data-role="none" style="float: none; width: 1.75em"><button type="button" is="paper-icon-button-light" class="autoSize"><i class="md-icon">open_in_browser</i></button></a>';
             }
+            html += '</div>';
 
             html += '</div>';
         }
@@ -592,6 +535,12 @@
             $('#fldPath', context).hide();
         }
 
+        if (item.Type == "Series" || item.Type == "Movie" || item.Type == "Trailer") {
+            $('#fldOriginalName', context).show();
+        } else {
+            $('#fldOriginalName', context).hide();
+        }
+
         if (item.Type == "Series") {
             $('#fldSeriesRuntime', context).show();
         } else {
@@ -719,28 +668,16 @@
             $('#tagsCollapsible', context).hide();
             $('#metadataSettingsCollapsible', context).hide();
             $('#fldPremiereDate', context).hide();
-            $('#fldSortName', context).hide();
             $('#fldDateAdded', context).hide();
             $('#fldYear', context).hide();
         } else {
             $('#tagsCollapsible', context).show();
             $('#metadataSettingsCollapsible', context).show();
             $('#fldPremiereDate', context).show();
-            $('#fldSortName', context).show();
             $('#fldDateAdded', context).show();
             $('#fldYear', context).show();
         }
 
-        Dashboard.getCurrentUser().then(function (user) {
-
-            if (LibraryBrowser.getMoreCommands(item, user).indexOf('identify') != -1) {
-
-                $('#btnIdentify', context).show();
-            } else {
-                $('#btnIdentify', context).hide();
-            }
-        });
-
         if (item.Type == "Movie" || item.Type == "Trailer" || item.Type == "BoxSet") {
             $('#keywordsCollapsible', context).show();
         } else {
@@ -754,14 +691,14 @@
         }
 
         if (item.Type == "Person") {
-            context.querySelector('#txtProductionYear').label = Globalize.translate('LabelBirthYear');
-            context.querySelector("#txtPremiereDate").label = Globalize.translate('LabelBirthDate');
-            context.querySelector("#txtEndDate").label = Globalize.translate('LabelDeathDate');
+            context.querySelector('#txtProductionYear').label(Globalize.translate('LabelBirthYear'));
+            context.querySelector("#txtPremiereDate").label(Globalize.translate('LabelBirthDate'));
+            context.querySelector("#txtEndDate").label(Globalize.translate('LabelDeathDate'));
             $('#fldPlaceOfBirth', context).show();
         } else {
-            context.querySelector('#txtProductionYear').label = Globalize.translate('LabelYear');
-            context.querySelector("#txtPremiereDate").label = Globalize.translate('LabelReleaseDate');
-            context.querySelector("#txtEndDate").label = Globalize.translate('LabelEndDate');
+            context.querySelector('#txtProductionYear').label(Globalize.translate('LabelYear'));
+            context.querySelector("#txtPremiereDate").label(Globalize.translate('LabelReleaseDate'));
+            context.querySelector("#txtEndDate").label(Globalize.translate('LabelEndDate'));
             $('#fldPlaceOfBirth', context).hide();
         }
 
@@ -775,13 +712,13 @@
             $('#fldIndexNumber', context).show();
 
             if (item.Type == "Episode") {
-                context.querySelector('#txtIndexNumber').label = Globalize.translate('LabelEpisodeNumber');
+                context.querySelector('#txtIndexNumber').label(Globalize.translate('LabelEpisodeNumber'));
             } else if (item.Type == "Season") {
-                context.querySelector('#txtIndexNumber').label = Globalize.translate('LabelSeasonNumber');
+                context.querySelector('#txtIndexNumber').label(Globalize.translate('LabelSeasonNumber'));
             } else if (item.Type == "Audio") {
-                context.querySelector('#txtIndexNumber').label = Globalize.translate('LabelTrackNumber');
+                context.querySelector('#txtIndexNumber').label(Globalize.translate('LabelTrackNumber'));
             } else {
-                context.querySelector('#txtIndexNumber').label = Globalize.translate('LabelNumber');
+                context.querySelector('#txtIndexNumber').label(Globalize.translate('LabelNumber'));
             }
         } else {
             $('#fldIndexNumber', context).hide();
@@ -791,26 +728,19 @@
             $('#fldParentIndexNumber', context).show();
 
             if (item.Type == "Episode") {
-                context.querySelector('#txtParentIndexNumber').label = Globalize.translate('LabelSeasonNumber');
+                context.querySelector('#txtParentIndexNumber').label(Globalize.translate('LabelSeasonNumber'));
             } else if (item.Type == "Audio") {
-                context.querySelector('#txtParentIndexNumber').label = Globalize.translate('LabelDiscNumber');
+                context.querySelector('#txtParentIndexNumber').label(Globalize.translate('LabelDiscNumber'));
             } else {
-                context.querySelector('#txtParentIndexNumber').label = Globalize.translate('LabelParentNumber');
+                context.querySelector('#txtParentIndexNumber').label(Globalize.translate('LabelParentNumber'));
             }
         } else {
             $('#fldParentIndexNumber', context).hide();
         }
 
-        if (item.Type == "Series") {
-            $('#fldDisplaySpecialsInline', context).show();
-        } else {
-            $('#fldDisplaySpecialsInline', context).hide();
-        }
-
         if (item.Type == "BoxSet") {
             $('#fldDisplayOrder', context).show();
 
-            $('#labelDisplayOrder', context).html(Globalize.translate('LabelTitleDisplayOrder'));
             $('#selectDisplayOrder', context).html('<option value="SortName">' + Globalize.translate('OptionSortName') + '</option><option value="PremiereDate">' + Globalize.translate('OptionReleaseDate') + '</option>');
         } else {
             $('#selectDisplayOrder', context).html('');
@@ -874,10 +804,9 @@
         }
         populateInternetProviderSettings(context, item, item.LockedFields);
 
-        context.querySelector('#chkDisplaySpecialsInline').checked = item.DisplaySpecialsWithSeasons || false;
-
         $('#txtPath', context).val(item.Path || '');
         $('#txtName', context).val(item.Name || "");
+        $('#txtOriginalName', context).val(item.OriginalTitle || "");
         context.querySelector('#txtOverview').value = item.Overview || '';
         $('#txtShortOverview', context).val(item.ShortOverview || "");
         $('#txtTagline', context).val((item.Taglines && item.Taglines.length ? item.Taglines[0] : ''));
@@ -927,7 +856,7 @@
 
         if (item.DateCreated) {
             try {
-                date = parseISO8601Date(item.DateCreated, { toLocal: true });
+                date = datetime.parseISO8601Date(item.DateCreated, true);
 
                 $('#txtDateAdded', context).val(date.toISOString().slice(0, 10));
             } catch (e) {
@@ -939,7 +868,7 @@
 
         if (item.PremiereDate) {
             try {
-                date = parseISO8601Date(item.PremiereDate, { toLocal: true });
+                date = datetime.parseISO8601Date(item.PremiereDate, true);
 
                 $('#txtPremiereDate', context).val(date.toISOString().slice(0, 10));
             } catch (e) {
@@ -951,7 +880,7 @@
 
         if (item.EndDate) {
             try {
-                date = parseISO8601Date(item.EndDate, { toLocal: true });
+                date = datetime.parseISO8601Date(item.EndDate, true);
 
                 $('#txtEndDate', context).val(date.toISOString().slice(0, 10));
             } catch (e) {
@@ -1038,21 +967,21 @@
         }
         var html = '';
         for (var i = 0; i < items.length; i++) {
-            html += '<paper-icon-item>';
+            html += '<div class="listItem">';
 
-            html += '<paper-fab mini style="background-color:#444;" icon="live-tv" item-icon></paper-fab>';
+            html += '<button type="button" is="emby-button" data-index="' + i + '" class="fab autoSize mini"><i class="md-icon">live_tv</i></button>';
 
-            html += '<paper-item-body>';
+            html += '<div class="listItemBody">';
 
             html += '<div class="textValue">';
             html += items[i];
             html += '</div>';
 
-            html += '</paper-item-body>';
+            html += '</div>';
 
-            html += '<paper-icon-button icon="delete" data-index="' + i + '" class="btnRemoveFromEditorList"></paper-icon-button>';
+            html += '<button type="button" is="paper-icon-button-light" data-index="' + i + '" class="btnRemoveFromEditorList autoSize"><i class="md-icon">delete</i></button>';
 
-            html += '</paper-icon-item>';
+            html += '</div>';
         }
 
         list.innerHTML = html;
@@ -1069,11 +998,11 @@
 
             var person = people[i];
 
-            html += '<paper-icon-item>';
+            html += '<div class="listItem">';
 
-            html += '<paper-fab class="btnEditPerson" data-index="' + i + '" mini style="background-color:#444;" icon="person" item-icon></paper-fab>';
+            html += '<button type="button" is="emby-button" data-index="' + i + '" class="btnEditPerson fab autoSize mini"><i class="md-icon">person</i></button>';
 
-            html += '<paper-item-body>';
+            html += '<div class="listItemBody">';
             html += '<a class="btnEditPerson clearLink" href="#" data-index="' + i + '">';
 
             html += '<div class="textValue">';
@@ -1081,15 +1010,15 @@
             html += '</div>';
 
             if (person.Role && person.Role != lastType) {
-                html += '<div secondary>' + (person.Role) + '</div>';
+                html += '<div class="secondary">' + (person.Role) + '</div>';
             }
 
             html += '</a>';
-            html += '</paper-item-body>';
+            html += '</div>';
 
-            html += '<paper-icon-button icon="delete" data-index="' + i + '" class="btnDeletePerson"></paper-icon-button>';
+            html += '<button type="button" is="paper-icon-button-light" data-index="' + i + '" class="btnDeletePerson autoSize"><i class="md-icon">delete</i></button>';
 
-            html += '</paper-icon-item>';
+            html += '</div>';
         }
 
         elem.innerHTML = html;
@@ -1119,7 +1048,10 @@
             var name = field.name;
             var value = field.value || field.name;
             var checkedHtml = currentFields.indexOf(value) == -1 ? ' checked' : '';
-            html += '<paper-checkbox class="selectLockedField" data-value="' + value + '" style="display:block;margin:1em 0;"' + checkedHtml + '>' + name + '</paper-checkbox>';
+            html += '<label>';
+            html += '<input type="checkbox" is="emby-checkbox" class="selectLockedField" data-value="' + value + '"' + checkedHtml + '/>';
+            html += '<span>' + name + '</span>';
+            html += '</label>';
         }
         return html;
     }
