@@ -75,7 +75,10 @@
                     html += "<div>";
                     html += "<span class='storeItemReviewText'>";
                     html += new Date(review.timestamp).toDateString();
-                    html += " " + RatingHelpers.getStoreRatingHtml(review.rating, review.id, review.name, true);
+                    if (review.rating) {
+                        html += '<iron-icon icon="star" style="color:#666;height:20px;width:20px;min-height:20px;min-width:20px;margin-right:.25em;"></iron-icon>';
+                        html += review.rating.toFixed(1);
+                    }
                     html += " " + review.title;
                     html += "</span>";
                     if (review.review) {
@@ -133,8 +136,12 @@
         RegistrationServices.renderPluginInfo(page, pkg, pluginSecurityInfo);
 
         //Ratings and Reviews
-        var ratingHtml = RatingHelpers.getStoreRatingHtml(pkg.avgRating, pkg.id, pkg.name);
-        ratingHtml += "<span class='storeReviewCount'>";
+        var ratingHtml = '';
+        if (pkg.avgRating) {
+            ratingHtml += '<iron-icon icon="star" style="color:#666;height:20px;width:20px;min-height:20px;min-width:20px;margin-right:.25em;"></iron-icon>';
+            ratingHtml += pkg.avgRating.toFixed(1);
+        }
+        ratingHtml += "<span>";
         ratingHtml += " " + Globalize.translate('ValueReviewCount').replace('{0}', pkg.totalRatings);
         ratingHtml += "</span>";
 
