@@ -147,7 +147,7 @@
 
         function initPage(tabContent) {
 
-            $('.itemsContainer', tabContent).on('needsrefresh', function () {
+            tabContent.querySelector('.itemsContainer').addEventListener('needsrefresh', function () {
 
                 reloadItems(tabContent);
             });
@@ -202,12 +202,13 @@
                 });
             });
 
-            tabContent.querySelector('.btnSelectView').addEventListener('click', function (e) {
+            var btnSelectView = tabContent.querySelector('.btnSelectView');
+            btnSelectView.addEventListener('click', function (e) {
 
                 libraryBrowser.showLayoutMenu(e.target, self.getCurrentViewStyle(), 'List,Poster,PosterCard'.split(','));
             });
 
-            tabContent.querySelector('.btnSelectView').addEventListener('layoutchange', function (e) {
+            btnSelectView.addEventListener('layoutchange', function (e) {
 
                 var viewStyle = e.detail.viewStyle;
                 getPageData(tabContent).view = viewStyle;
